# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBytes, StrictInt, StrictStr
from typing import Optional, Tuple, Union
from typing_extensions import Annotated
from ringer_business.models.menu_response import MenuResponse
from ringer_business.models.paginated_menu_list_response import PaginatedMenuListResponse

from ringer_business.api_client import ApiClient, RequestSerialized
from ringer_business.api_response import ApiResponse
from ringer_business.rest import RESTResponseType


class SiteFeaturesMenusApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_site_menu(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        name: StrictStr,
        fail_over_destination_code: StrictStr,
        pin: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="Audio file for the menu greeting.")] = None,
        option_routes_0: Annotated[Optional[StrictStr], Field(description="Destination code for key '0'.")] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Annotated[Optional[StrictStr], Field(description="Destination code for key '*'.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MenuResponse:
        """Create Menu for a Site

        Add a new menu (auto attendant) to your site. Greeting can be uploaded.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param name: (required)
        :type name: str
        :param fail_over_destination_code: (required)
        :type fail_over_destination_code: str
        :param pin:
        :type pin: str
        :param greeting: Audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0: Destination code for key '0'.
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_: Destination code for key '*'.
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_menu_serialize(
            site_id=site_id,
            name=name,
            fail_over_destination_code=fail_over_destination_code,
            pin=pin,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_site_menu_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        name: StrictStr,
        fail_over_destination_code: StrictStr,
        pin: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="Audio file for the menu greeting.")] = None,
        option_routes_0: Annotated[Optional[StrictStr], Field(description="Destination code for key '0'.")] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Annotated[Optional[StrictStr], Field(description="Destination code for key '*'.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MenuResponse]:
        """Create Menu for a Site

        Add a new menu (auto attendant) to your site. Greeting can be uploaded.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param name: (required)
        :type name: str
        :param fail_over_destination_code: (required)
        :type fail_over_destination_code: str
        :param pin:
        :type pin: str
        :param greeting: Audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0: Destination code for key '0'.
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_: Destination code for key '*'.
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_menu_serialize(
            site_id=site_id,
            name=name,
            fail_over_destination_code=fail_over_destination_code,
            pin=pin,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_site_menu_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        name: StrictStr,
        fail_over_destination_code: StrictStr,
        pin: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="Audio file for the menu greeting.")] = None,
        option_routes_0: Annotated[Optional[StrictStr], Field(description="Destination code for key '0'.")] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Annotated[Optional[StrictStr], Field(description="Destination code for key '*'.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Menu for a Site

        Add a new menu (auto attendant) to your site. Greeting can be uploaded.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param name: (required)
        :type name: str
        :param fail_over_destination_code: (required)
        :type fail_over_destination_code: str
        :param pin:
        :type pin: str
        :param greeting: Audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0: Destination code for key '0'.
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_: Destination code for key '*'.
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_site_menu_serialize(
            site_id=site_id,
            name=name,
            fail_over_destination_code=fail_over_destination_code,
            pin=pin,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_site_menu_serialize(
        self,
        site_id,
        name,
        fail_over_destination_code,
        pin,
        greeting,
        option_routes_0,
        option_routes_1,
        option_routes_2,
        option_routes_3,
        option_routes_4,
        option_routes_5,
        option_routes_6,
        option_routes_7,
        option_routes_8,
        option_routes_9,
        option_routes_,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if name is not None:
            _form_params.append(('name', name))
        if pin is not None:
            _form_params.append(('pin', pin))
        if fail_over_destination_code is not None:
            _form_params.append(('fail_over_destination_code', fail_over_destination_code))
        if greeting is not None:
            _files['greeting'] = greeting
        if option_routes_0 is not None:
            _form_params.append(('option_routes[0]', option_routes_0))
        if option_routes_1 is not None:
            _form_params.append(('option_routes[1]', option_routes_1))
        if option_routes_2 is not None:
            _form_params.append(('option_routes[2]', option_routes_2))
        if option_routes_3 is not None:
            _form_params.append(('option_routes[3]', option_routes_3))
        if option_routes_4 is not None:
            _form_params.append(('option_routes[4]', option_routes_4))
        if option_routes_5 is not None:
            _form_params.append(('option_routes[5]', option_routes_5))
        if option_routes_6 is not None:
            _form_params.append(('option_routes[6]', option_routes_6))
        if option_routes_7 is not None:
            _form_params.append(('option_routes[7]', option_routes_7))
        if option_routes_8 is not None:
            _form_params.append(('option_routes[8]', option_routes_8))
        if option_routes_9 is not None:
            _form_params.append(('option_routes[9]', option_routes_9))
        if option_routes_ is not None:
            _form_params.append(('option_routes[*]', option_routes_))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/sites/{siteId}/menus',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_site_menu_by_id(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Menu

        Permanently delete a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_site_menu_by_id_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Menu

        Permanently delete a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_site_menu_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Menu

        Permanently delete a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_site_menu_by_id_serialize(
        self,
        site_id,
        menu_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if menu_id is not None:
            _path_params['menuId'] = menu_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/sites/{siteId}/menus/{menuId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_site_menu_by_id(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MenuResponse:
        """Get Menu Details

        Retrieve the details of a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_site_menu_by_id_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MenuResponse]:
        """Get Menu Details

        Retrieve the details of a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_site_menu_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Menu Details

        Retrieve the details of a specific menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_site_menu_by_id_serialize(
        self,
        site_id,
        menu_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if menu_id is not None:
            _path_params['menuId'] = menu_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/sites/{siteId}/menus/{menuId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_site_menus(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        page: Annotated[Optional[StrictInt], Field(description="Page number for pagination.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of menus per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedMenuListResponse:
        """List Menus for a Site

        Retrieve a paginated list of all menus (auto attendants) that belong to a site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param page: Page number for pagination.
        :type page: int
        :param page_size: Number of menus per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_menus_serialize(
            site_id=site_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedMenuListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_site_menus_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        page: Annotated[Optional[StrictInt], Field(description="Page number for pagination.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of menus per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedMenuListResponse]:
        """List Menus for a Site

        Retrieve a paginated list of all menus (auto attendants) that belong to a site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param page: Page number for pagination.
        :type page: int
        :param page_size: Number of menus per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_menus_serialize(
            site_id=site_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedMenuListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_site_menus_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        page: Annotated[Optional[StrictInt], Field(description="Page number for pagination.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of menus per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Menus for a Site

        Retrieve a paginated list of all menus (auto attendants) that belong to a site.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param page: Page number for pagination.
        :type page: int
        :param page_size: Number of menus per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_site_menus_serialize(
            site_id=site_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedMenuListResponse",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_site_menus_serialize(
        self,
        site_id,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/sites/{siteId}/menus',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def transfer_site_menu(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        new_site_id: Annotated[StrictInt, Field(description="The unique identifier of the target site for the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MenuResponse:
        """Transfer Menu to Another Site

        Moves a menu from its current site (specified in the path)  to a new target site (specified in the request body) within the same customer account. 

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param new_site_id: The unique identifier of the target site for the menu. (required)
        :type new_site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transfer_site_menu_serialize(
            site_id=site_id,
            menu_id=menu_id,
            new_site_id=new_site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def transfer_site_menu_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        new_site_id: Annotated[StrictInt, Field(description="The unique identifier of the target site for the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MenuResponse]:
        """Transfer Menu to Another Site

        Moves a menu from its current site (specified in the path)  to a new target site (specified in the request body) within the same customer account. 

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param new_site_id: The unique identifier of the target site for the menu. (required)
        :type new_site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transfer_site_menu_serialize(
            site_id=site_id,
            menu_id=menu_id,
            new_site_id=new_site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def transfer_site_menu_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        new_site_id: Annotated[StrictInt, Field(description="The unique identifier of the target site for the menu.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Transfer Menu to Another Site

        Moves a menu from its current site (specified in the path)  to a new target site (specified in the request body) within the same customer account. 

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param new_site_id: The unique identifier of the target site for the menu. (required)
        :type new_site_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._transfer_site_menu_serialize(
            site_id=site_id,
            menu_id=menu_id,
            new_site_id=new_site_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _transfer_site_menu_serialize(
        self,
        site_id,
        menu_id,
        new_site_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if menu_id is not None:
            _path_params['menuId'] = menu_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if new_site_id is not None:
            _form_params.append(('new_site_id', new_site_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/sites/{siteId}/menus/{menuId}/transfer',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_site_menu_by_id(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        name: Optional[StrictStr] = None,
        pin: Optional[StrictStr] = None,
        fail_over_destination_code: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="New audio file for the menu greeting.")] = None,
        option_routes_0: Optional[StrictStr] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MenuResponse:
        """Update Menu Configuration

        Updates an existing menu. For `multipart/form-data`, provide only the fields to change. Audio files can be updated.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param name:
        :type name: str
        :param pin:
        :type pin: str
        :param fail_over_destination_code:
        :type fail_over_destination_code: str
        :param greeting: New audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0:
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_:
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            name=name,
            pin=pin,
            fail_over_destination_code=fail_over_destination_code,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_site_menu_by_id_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        name: Optional[StrictStr] = None,
        pin: Optional[StrictStr] = None,
        fail_over_destination_code: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="New audio file for the menu greeting.")] = None,
        option_routes_0: Optional[StrictStr] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MenuResponse]:
        """Update Menu Configuration

        Updates an existing menu. For `multipart/form-data`, provide only the fields to change. Audio files can be updated.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param name:
        :type name: str
        :param pin:
        :type pin: str
        :param fail_over_destination_code:
        :type fail_over_destination_code: str
        :param greeting: New audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0:
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_:
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            name=name,
            pin=pin,
            fail_over_destination_code=fail_over_destination_code,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_site_menu_by_id_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        name: Optional[StrictStr] = None,
        pin: Optional[StrictStr] = None,
        fail_over_destination_code: Optional[StrictStr] = None,
        greeting: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="New audio file for the menu greeting.")] = None,
        option_routes_0: Optional[StrictStr] = None,
        option_routes_1: Optional[StrictStr] = None,
        option_routes_2: Optional[StrictStr] = None,
        option_routes_3: Optional[StrictStr] = None,
        option_routes_4: Optional[StrictStr] = None,
        option_routes_5: Optional[StrictStr] = None,
        option_routes_6: Optional[StrictStr] = None,
        option_routes_7: Optional[StrictStr] = None,
        option_routes_8: Optional[StrictStr] = None,
        option_routes_9: Optional[StrictStr] = None,
        option_routes_: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Menu Configuration

        Updates an existing menu. For `multipart/form-data`, provide only the fields to change. Audio files can be updated.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param name:
        :type name: str
        :param pin:
        :type pin: str
        :param fail_over_destination_code:
        :type fail_over_destination_code: str
        :param greeting: New audio file for the menu greeting.
        :type greeting: bytearray
        :param option_routes_0:
        :type option_routes_0: str
        :param option_routes_1:
        :type option_routes_1: str
        :param option_routes_2:
        :type option_routes_2: str
        :param option_routes_3:
        :type option_routes_3: str
        :param option_routes_4:
        :type option_routes_4: str
        :param option_routes_5:
        :type option_routes_5: str
        :param option_routes_6:
        :type option_routes_6: str
        :param option_routes_7:
        :type option_routes_7: str
        :param option_routes_8:
        :type option_routes_8: str
        :param option_routes_9:
        :type option_routes_9: str
        :param option_routes_:
        :type option_routes_: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_site_menu_by_id_serialize(
            site_id=site_id,
            menu_id=menu_id,
            name=name,
            pin=pin,
            fail_over_destination_code=fail_over_destination_code,
            greeting=greeting,
            option_routes_0=option_routes_0,
            option_routes_1=option_routes_1,
            option_routes_2=option_routes_2,
            option_routes_3=option_routes_3,
            option_routes_4=option_routes_4,
            option_routes_5=option_routes_5,
            option_routes_6=option_routes_6,
            option_routes_7=option_routes_7,
            option_routes_8=option_routes_8,
            option_routes_9=option_routes_9,
            option_routes_=option_routes_,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_site_menu_by_id_serialize(
        self,
        site_id,
        menu_id,
        name,
        pin,
        fail_over_destination_code,
        greeting,
        option_routes_0,
        option_routes_1,
        option_routes_2,
        option_routes_3,
        option_routes_4,
        option_routes_5,
        option_routes_6,
        option_routes_7,
        option_routes_8,
        option_routes_9,
        option_routes_,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if menu_id is not None:
            _path_params['menuId'] = menu_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if name is not None:
            _form_params.append(('name', name))
        if pin is not None:
            _form_params.append(('pin', pin))
        if fail_over_destination_code is not None:
            _form_params.append(('fail_over_destination_code', fail_over_destination_code))
        if greeting is not None:
            _files['greeting'] = greeting
        if option_routes_0 is not None:
            _form_params.append(('option_routes[0]', option_routes_0))
        if option_routes_1 is not None:
            _form_params.append(('option_routes[1]', option_routes_1))
        if option_routes_2 is not None:
            _form_params.append(('option_routes[2]', option_routes_2))
        if option_routes_3 is not None:
            _form_params.append(('option_routes[3]', option_routes_3))
        if option_routes_4 is not None:
            _form_params.append(('option_routes[4]', option_routes_4))
        if option_routes_5 is not None:
            _form_params.append(('option_routes[5]', option_routes_5))
        if option_routes_6 is not None:
            _form_params.append(('option_routes[6]', option_routes_6))
        if option_routes_7 is not None:
            _form_params.append(('option_routes[7]', option_routes_7))
        if option_routes_8 is not None:
            _form_params.append(('option_routes[8]', option_routes_8))
        if option_routes_9 is not None:
            _form_params.append(('option_routes[9]', option_routes_9))
        if option_routes_ is not None:
            _form_params.append(('option_routes[*]', option_routes_))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/sites/{siteId}/menus/{menuId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def upload_site_menu_greeting(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        greeting: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="Audio file for the menu greeting (e.g., .mp3, .wav).")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MenuResponse:
        """Upload Menu Greeting

        Upload or update the greeting audio file for the specified menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param greeting: Audio file for the menu greeting (e.g., .mp3, .wav). (required)
        :type greeting: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_site_menu_greeting_serialize(
            site_id=site_id,
            menu_id=menu_id,
            greeting=greeting,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def upload_site_menu_greeting_with_http_info(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        greeting: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="Audio file for the menu greeting (e.g., .mp3, .wav).")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MenuResponse]:
        """Upload Menu Greeting

        Upload or update the greeting audio file for the specified menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param greeting: Audio file for the menu greeting (e.g., .mp3, .wav). (required)
        :type greeting: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_site_menu_greeting_serialize(
            site_id=site_id,
            menu_id=menu_id,
            greeting=greeting,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def upload_site_menu_greeting_without_preload_content(
        self,
        site_id: Annotated[StrictStr, Field(description="The unique identifier of the site.")],
        menu_id: Annotated[StrictInt, Field(description="The unique identifier of the menu.")],
        greeting: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="Audio file for the menu greeting (e.g., .mp3, .wav).")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload Menu Greeting

        Upload or update the greeting audio file for the specified menu.

        :param site_id: The unique identifier of the site. (required)
        :type site_id: str
        :param menu_id: The unique identifier of the menu. (required)
        :type menu_id: int
        :param greeting: Audio file for the menu greeting (e.g., .mp3, .wav). (required)
        :type greeting: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_site_menu_greeting_serialize(
            site_id=site_id,
            menu_id=menu_id,
            greeting=greeting,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MenuResponse",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _upload_site_menu_greeting_serialize(
        self,
        site_id,
        menu_id,
        greeting,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if site_id is not None:
            _path_params['siteId'] = site_id
        if menu_id is not None:
            _path_params['menuId'] = menu_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if greeting is not None:
            _files['greeting'] = greeting
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oAuth2'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/sites/{siteId}/menus/{menuId}/upload',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_locations_api import SiteFeaturesLocationsApi


class TestSiteFeaturesLocationsApi(unittest.TestCase):
    """SiteFeaturesLocationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesLocationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_location(self) -> None:
        """Test case for create_site_location

        Create a Location for a Site
        """
        pass

    def test_delete_site_location_by_id(self) -> None:
        """Test case for delete_site_location_by_id

        Delete a Location
        """
        pass

    def test_get_site_location_by_id(self) -> None:
        """Test case for get_site_location_by_id

        Get Location Details
        """
        pass

    def test_list_site_locations(self) -> None:
        """Test case for list_site_locations

        List Locations for a Site
        """
        pass

    def test_update_site_location_by_id(self) -> None:
        """Test case for update_site_location_by_id

        Update Location Details
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.credit_cards_api import CreditCardsApi


class TestCreditCardsApi(unittest.TestCase):
    """CreditCardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CreditCardsApi()

    def tearDown(self) -> None:
        pass

    def test_create_credit_card(self) -> None:
        """Test case for create_credit_card

        Add a New Credit Card
        """
        pass

    def test_list_credit_cards(self) -> None:
        """Test case for list_credit_cards

        List Credit Cards
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.e911_response import E911Response

class TestE911Response(unittest.TestCase):
    """E911Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> E911Response:
        """Test E911Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `E911Response`
        """
        model = E911Response()
        if include_optional:
            return E911Response(
                name = 'Headquarters - Main Lobby E911',
                caller_id_name = 'Innovatech Solutions - Lobby',
                house_number = '2150',
                house_number_suffix = 'Suite 100',
                street = 'West 29th Avenue',
                city = 'Denver',
                state_province = 'CO',
                postal_code = '80211',
                country_code = 'US',
                id = 19,
                site_id = 6,
                validated = True,
                did_number = '+13035550100',
                links = [
                    ringer_business.models.link.Link(
                        href = '/example/resource/123', 
                        rel = 'self', 
                        method = 'GET', 
                        title = 'View Example Resource', )
                    ]
            )
        else:
            return E911Response(
                name = 'Headquarters - Main Lobby E911',
                caller_id_name = 'Innovatech Solutions - Lobby',
                house_number = '2150',
                street = 'West 29th Avenue',
                city = 'Denver',
                state_province = 'CO',
                postal_code = '80211',
                country_code = 'US',
                id = 19,
                site_id = 6,
                validated = True,
        )
        """

    def testE911Response(self):
        """Test E911Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API - Timezones

    This API provides an endpoint for listing available Timezones. Timezones are crucial for configuring time-sensitive features within the phone system, such as schedules, business hours, and call logging timestamps. This endpoint allows developers to retrieve a comprehensive list of supported IANA timezone identifiers. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.timezones_api import TimezonesApi


class TestTimezonesApi(unittest.TestCase):
    """TimezonesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TimezonesApi()

    def tearDown(self) -> None:
        pass

    def test_list_available_timezones(self) -> None:
        """Test case for list_available_timezones

        List Available Timezones
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ScheduleUpdateRequestDataAttributes(BaseModel):
    """
    ScheduleUpdateRequestDataAttributes
    """ # noqa: E501
    name: Optional[StrictStr] = None
    time_zone: Optional[StrictStr] = None
    start_hour: Optional[StrictStr] = None
    start_minute: Optional[StrictStr] = None
    end_hour: Optional[StrictStr] = None
    end_minute: Optional[StrictStr] = None
    start_weekday: Optional[StrictStr] = None
    end_weekday: Optional[StrictStr] = None
    exceptions: Optional[StrictStr] = None
    positive_destination_code: Optional[StrictStr] = None
    negative_destination_code: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["name", "time_zone", "start_hour", "start_minute", "end_hour", "end_minute", "start_weekday", "end_weekday", "exceptions", "positive_destination_code", "negative_destination_code"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScheduleUpdateRequestDataAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if time_zone (nullable) is None
        # and model_fields_set contains the field
        if self.time_zone is None and "time_zone" in self.model_fields_set:
            _dict['time_zone'] = None

        # set to None if start_hour (nullable) is None
        # and model_fields_set contains the field
        if self.start_hour is None and "start_hour" in self.model_fields_set:
            _dict['start_hour'] = None

        # set to None if start_minute (nullable) is None
        # and model_fields_set contains the field
        if self.start_minute is None and "start_minute" in self.model_fields_set:
            _dict['start_minute'] = None

        # set to None if end_hour (nullable) is None
        # and model_fields_set contains the field
        if self.end_hour is None and "end_hour" in self.model_fields_set:
            _dict['end_hour'] = None

        # set to None if end_minute (nullable) is None
        # and model_fields_set contains the field
        if self.end_minute is None and "end_minute" in self.model_fields_set:
            _dict['end_minute'] = None

        # set to None if start_weekday (nullable) is None
        # and model_fields_set contains the field
        if self.start_weekday is None and "start_weekday" in self.model_fields_set:
            _dict['start_weekday'] = None

        # set to None if end_weekday (nullable) is None
        # and model_fields_set contains the field
        if self.end_weekday is None and "end_weekday" in self.model_fields_set:
            _dict['end_weekday'] = None

        # set to None if exceptions (nullable) is None
        # and model_fields_set contains the field
        if self.exceptions is None and "exceptions" in self.model_fields_set:
            _dict['exceptions'] = None

        # set to None if positive_destination_code (nullable) is None
        # and model_fields_set contains the field
        if self.positive_destination_code is None and "positive_destination_code" in self.model_fields_set:
            _dict['positive_destination_code'] = None

        # set to None if negative_destination_code (nullable) is None
        # and model_fields_set contains the field
        if self.negative_destination_code is None and "negative_destination_code" in self.model_fields_set:
            _dict['negative_destination_code'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScheduleUpdateRequestDataAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "time_zone": obj.get("time_zone"),
            "start_hour": obj.get("start_hour"),
            "start_minute": obj.get("start_minute"),
            "end_hour": obj.get("end_hour"),
            "end_minute": obj.get("end_minute"),
            "start_weekday": obj.get("start_weekday"),
            "end_weekday": obj.get("end_weekday"),
            "exceptions": obj.get("exceptions"),
            "positive_destination_code": obj.get("positive_destination_code"),
            "negative_destination_code": obj.get("negative_destination_code")
        })
        return _obj





# coding: utf-8

"""
    Ringer Business API - Credit Card Management

    This API provides endpoints for managing credit card payment methods associated with a customer account. It allows developers to: - List existing credit cards. - Add a new credit card. - Retrieve details of a specific credit card. - Update information for an existing credit card. - Delete a credit card. - Verify a newly added credit card.  Proper security and PCI compliance considerations are paramount when handling credit card data. These endpoints are designed to interact with a secure payment processing backend. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from ringer_business.models.link import Link
from typing import Optional, Set
from typing_extensions import Self

class CreditCardResponse(BaseModel):
    """
    Detailed information about a stored credit card (excluding sensitive full PAN).
    """ # noqa: E501
    id: StrictInt = Field(description="Unique identifier for the credit card record.")
    name: StrictStr = Field(description="A custom name or label for the credit card (e.g., \"Work Visa\", \"Personal Amex\").")
    last4: StrictStr = Field(description="The last four digits of the credit card number.")
    brand: StrictStr = Field(description="The brand of the credit card (e.g., Visa, Mastercard, American Express).")
    exp_month: StrictInt = Field(description="The expiration month of the credit card (1-12).")
    exp_year: StrictInt = Field(description="The expiration year of the credit card (e.g., 2025).")
    priority: Annotated[int, Field(le=100, strict=True, ge=0)] = Field(description="Priority for payment processing (higher numbers typically processed first). Range 0-100.")
    active: StrictBool = Field(description="Indicates if the card is active for payments.")
    verified: StrictBool = Field(description="Indicates if the card has been successfully verified.")
    expired: StrictBool = Field(description="Indicates if the card is currently expired based on its expiration date.")
    links: Optional[List[Link]] = Field(default=None, description="HATEOAS links related to this credit card.")
    __properties: ClassVar[List[str]] = ["id", "name", "last4", "brand", "exp_month", "exp_year", "priority", "active", "verified", "expired", "links"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreditCardResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "expired",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item_links in self.links:
                if _item_links:
                    _items.append(_item_links.to_dict())
            _dict['links'] = _items
        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict['links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreditCardResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "last4": obj.get("last4"),
            "brand": obj.get("brand"),
            "exp_month": obj.get("exp_month"),
            "exp_year": obj.get("exp_year"),
            "priority": obj.get("priority"),
            "active": obj.get("active"),
            "verified": obj.get("verified"),
            "expired": obj.get("expired"),
            "links": [Link.from_dict(_item) for _item in obj["links"]] if obj.get("links") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Ringer Business API - Account Management

    This API provides endpoints for managing customer accounts in the Ringer Business system. It allows for retrieving account details, updating account information, managing account status (activation/closure), and updating associated addresses.  Account operations typically require authentication and appropriate permissions (e.g., administrator role for certain updates). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ringer_business.models.account_response import AccountResponse
from ringer_business.models.account_update_request import AccountUpdateRequest
from ringer_business.models.address_core import AddressCore
from ringer_business.models.address_response import AddressResponse
from ringer_business.models.error import Error
from ringer_business.models.link import Link
from ringer_business.models.user_summary import UserSummary



# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class E911Core(BaseModel):
    """
    Core address and identification information for an E911 record.
    """ # noqa: E501
    name: StrictStr = Field(description="A descriptive name for this E911 record.")
    caller_id_name: StrictStr = Field(description="The name to be displayed to the PSAP for 911 calls from this address.")
    house_number: StrictStr = Field(description="Street number.")
    house_number_suffix: Optional[StrictStr] = Field(default=None, description="Street number suffix (e.g., \"A\", \"Unit 100\").")
    street: StrictStr = Field(description="Street name.")
    city: StrictStr = Field(description="City name.")
    state_province: StrictStr = Field(description="State or province code.")
    postal_code: StrictStr = Field(description="Postal or ZIP code.")
    country_code: StrictStr = Field(description="Two-letter ISO 3166-1 alpha-2 country code.")
    __properties: ClassVar[List[str]] = ["name", "caller_id_name", "house_number", "house_number_suffix", "street", "city", "state_province", "postal_code", "country_code"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of E911Core from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if house_number_suffix (nullable) is None
        # and model_fields_set contains the field
        if self.house_number_suffix is None and "house_number_suffix" in self.model_fields_set:
            _dict['house_number_suffix'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of E911Core from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "caller_id_name": obj.get("caller_id_name"),
            "house_number": obj.get("house_number"),
            "house_number_suffix": obj.get("house_number_suffix"),
            "street": obj.get("street"),
            "city": obj.get("city"),
            "state_province": obj.get("state_province"),
            "postal_code": obj.get("postal_code"),
            "country_code": obj.get("country_code")
        })
        return _obj


